@@ -1,8 +1,5 @@
 import pandas
 
-def something():
-    print('Hello')
-
 def load_csv(path):
     result = pandas.read_csv(path)
     print(result)
\ No newline at end of file
